//--------------------------------------------------------------
// File     : stm32_ub_logview.c
// Datum    : 29.03.2013
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.0
// Module   : STM32_UB_UART, Retarget_printf
// Funktion : Grafische Datenanzeige per PC-Programm "Logview.exe"
//
// Hinweis  : Die Einstellung der Baudrate und die Anzahl
//            der benutzten Logging-Kanlen muss zu den
//            Settings vom INI-File der Logview.exe passen
//            (sonst werden keine Daten angezeigt)
// 
//            Der Datentyp der Kanle ist als "int16_t" angelegt
//--------------------------------------------------------------


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_logview.h"


//--------------------------------------------------------------
// Init der LogView Struktur und vom UART
// kanal_anz = Anzahl der Benutzten Logging-Kanle
//             [1...LOGVIEW_MAX_KANAL]
// Return_wert :
//  -> ERROR   , wenn Initialisierung fehlgeschlagen
//  -> SUCCESS , wenn Initialisierung ok war
//--------------------------------------------------------------
ErrorStatus UB_Logview_Init(uint8_t kanal_anz)
{
  uint8_t n;

  if(kanal_anz>LOGVIEW_MAX_KANAL) return(ERROR);

  // Init der UART
  UB_Uart_Init();

  // Anzahl der Kanle speichern
  LOGVIEW.kan_anz=kanal_anz;

  // Alle Kanle mit 0 initialisieren
  for(n=0;n<kanal_anz;n++) {
    LOGVIEW.kanal[n]=0;
  }

  return(SUCCESS);
}

//--------------------------------------------------------------
// sendet einen kompleten LogView-Frame per UART
// mit den Daten aller Kanlen
//--------------------------------------------------------------
void UB_Logview_SendFrame(UART_NAME_t uart)
{
  char buf[10];
  uint8_t n;

  // Startkennung vom Frame
  strcpy(LOGVIEW.tx_buf,"$1;1;;");
  // Daten aller Kanle anhngen
  for(n=0;n<LOGVIEW.kan_anz;n++) {
    sprintf(buf,"%d;",LOGVIEW.kanal[n]);
    strcat(LOGVIEW.tx_buf,buf);
  }
  // Endekennung anhngen
  strcpy(buf,"0");
  strcat(LOGVIEW.tx_buf,buf);
  // Frame senden (mit CarriageReturn und LineFeed)
  UB_Uart_SendString(COM2,LOGVIEW.tx_buf,CRLF);
}

